JsSemanticValue

Struct JsSemanticValue 

pub struct JsSemanticValue { /* private fields */ }
Computed semantic value (output of NSR inference)

Implementations

Source

impl JsSemanticValue

pub fn instance_of<V: NapiRaw>(env: Env, value: V) -> Result<bool>

Source

impl JsSemanticValue

Source

impl JsSemanticValue

pub fn integer(n: i64) -> Self

Create an integer value

pub fn float(n: f64) -> Self

Create a float value

pub fn boolean(b: bool) -> Self

Create a boolean value

pub fn string(s: String) -> Self

Create a string value

pub fn symbol(s: String) -> Self

Create a symbol value

pub fn actions(actions: Vec<String>) -> Self

Create an action sequence (for SCAN-like tasks)

pub fn list(items: Vec<&JsSemanticValue>) -> Self

Create a list of values

pub fn null() -> Self

Create a null value

pub fn as_integer(&self) -> Option<i64>

Get integer value if this is an integer

pub fn as_float(&self) -> Option<f64>

Get float value if this is a float

pub fn as_string(&self) -> Option<String>

Get string value if this is a string or symbol

pub fn as_actions(&self) -> Option<Vec<String>>

Get action sequence if this is an action sequence

pub fn is_error(&self) -> bool

Check if this is an error

pub fn is_null(&self) -> bool

Check if this is null

pub fn to_string(&self) -> String